mysql.stmt.bind_in.In_U_Decimal

Package mysql :: Package stmt :: Module bind_in :: Class In_U_Decimal |
[hide private]
[frames] | no frames]

# Class In_U_Decimal

    object --+
             |
    Input_Bind --+
                 |
      Base_Decimal --+
                     |
                    In_U_Decimal

Unsigned Decimal input binding.

Warning: Decimal input binding is broken in server versions 5.0.18 and older. See http://bugs.mysql.com/bug.php?id=16511

The value must be a `decimal.Decimal` object. Raises `OverflowError` when `execute` is called if the value is negative.

Instance Methods | [hide private]
`` | __new__(T, S, ...) Returns a new object with type S, a subtype of T...
Inherited from `Base_Decimal`: `__init__` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables | [hide private]
`` | __pyx_vtable__ = `<PyCObject object at 0x852e7a0>`

Instance Variables | [hide private]
Inherited from `Base_Decimal` (private): `_allow_negative`, `_value` Inherited from `Input_Bind` (private): `_buffer`, `_buffer_length`, `_buffer_type`, `_is_null`, `_is_unsigned`, `_length`, `_what`, `_who`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __new__(T, S, ...) |
    Returns:
        a new object with type S, a subtype of T
Overrides: Base_Decimal.__new__

Class Variable Details | [hide private]

    ### __pyx_vtable__ Value:
        <PyCObject object at 0x852e7a0>